@@ -1,4 +1,5 @@
-import React, {PropTypes} from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 
 const STYLE = {fill: "#0096fd", stroke: "#fff", cursor: "move"};
 
