@@ -1,5 +1,6 @@
 import {Record, List, Map, fromJS} from 'immutable';
 import {MODE_IDLE} from './constants';
+import {SNAP_MASK} from './utils/snap';
 
 let safeLoadMapList = (mapList, Model, defaultMap) => {
   return mapList
@@ -279,6 +280,12 @@ export class State extends Record({
 
   viewer2D: new Map(),
 
+  mouse: new Map(),
+
+  zoom: 0,
+
+  snapMask: SNAP_MASK,
+
   snapElements: new List(),
   activeSnapElement: null,
 
@@ -299,6 +306,12 @@ export class State extends Record({
 
       viewer2D: new Map(json.viewer2D || {}),
 
+      mouse: new Map({ x: 0, y: 0 }),
+
+      zoom: 0,
+
+      snapMask: SNAP_MASK,
+
       drawingSupport: new Map(json.drawingSupport || {}),
       draggingSupport: new Map(json.draggingSupport || {}),
       rotatingSupport: new Map(json.rotatingSupport || {}),
