@@ -1,4 +1,4 @@
-import {Seq, Map, List} from "immutable";
+import { Seq, Map, List } from "immutable";
 import {
   LOAD_PROJECT,
   NEW_PROJECT,
@@ -17,10 +17,13 @@ import {
   ROLLBACK,
   SET_PROJECT_PROPERTIES,
   OPEN_PROJECT_CONFIGURATOR,
-  INIT_CATALOG
+  INIT_CATALOG,
+  UPDATE_MOUSE_COORDS,
+  UPDATE_ZOOM_SCALE,
+  TOGGLE_SNAP
 } from '../constants';
 
-import {State, Scene, Guide, Catalog} from "../models";
+import { State, Scene, Guide, Catalog } from "../models";
 
 import {
   removeLine,
@@ -42,7 +45,6 @@ import {
 export default function (state, action) {
 
   switch (action.type) {
-
     case NEW_PROJECT:
       return newProject(state);
 
@@ -88,6 +90,15 @@ export default function (state, action) {
     case INIT_CATALOG:
       return initCatalog(state, action.catalog);
 
+    case UPDATE_MOUSE_COORDS:
+      return updateMouseCoord(state, action.coords);
+
+    case UPDATE_ZOOM_SCALE:
+      return updateZoomScale(state, action.scale);
+
+    case TOGGLE_SNAP:
+      return toggleSnap(state, action.mask);
+
     default:
       return state;
 
@@ -104,10 +115,9 @@ function newProject(state) {
 }
 
 function loadProject(state, sceneJSON) {
-  return new State({scene: sceneJSON, catalog: state.catalog.toJS()});
+  return new State({ scene: sceneJSON, catalog: state.catalog.toJS() });
 }
 
-
 function setProperties(state, properties) {
   let scene = state.scene;
   scene = scene.set('layers', scene.layers.map(layer => setPropertiesOnSelected(layer, properties)));
@@ -162,7 +172,7 @@ function remove(state) {
   let catalog = state.catalog;
 
   scene = scene.updateIn(['layers', scene.selectedLayer], layer => layer.withMutations(layer => {
-    let {lines: selectedLines, holes: selectedHoles, items: selectedItems} = layer.selected;
+    let { lines: selectedLines, holes: selectedHoles, items: selectedItems } = layer.selected;
     unselectAllOp(layer);
     selectedLines.forEach(lineID => removeLine(layer, lineID));
     selectedHoles.forEach(holeID => removeHole(layer, holeID));
@@ -231,7 +241,6 @@ function setProjectProperties(state, properties) {
   });
 }
 
-
 function openProjectConfigurator(state) {
   return state.merge({
     mode: MODE_CONFIGURING_PROJECT,
@@ -241,3 +250,15 @@ function openProjectConfigurator(state) {
 function initCatalog(state, catalog) {
   return state.set('catalog', new Catalog(catalog));
 }
+
+function updateMouseCoord(state, coords) {
+  return state.set('mouse', new Map(coords));
+}
+
+function updateZoomScale(state, scale) {
+  return state.set('zoom', scale);
+}
+
+function toggleSnap(state, mask) {
+  return state.set('snapMask', mask);
+}
